package com.dj.action.sys;

import org.apache.log4j.Logger;
import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;
import org.springframework.beans.factory.annotation.Autowired;
import com.dj.action.base.BaseAction;
import com.dj.pageModel.base.Json;
import com.dj.pageModel.sys.Post;
import com.dj.service.sys.PostServiceI;
import com.dj.util.base.ExceptionUtil;
import com.opensymphony.xwork2.ModelDriven;

/**
 * 岗位ACTION
 * 
 * @author lili
 * 
 */
@Action(value = "post", results = {
		@Result(name = "post", location = "/general/admin/post.jsp"),
		@Result(name = "postAdd", location = "/general/admin/postAdd.jsp"),
		@Result(name = "postEdit", location = "/general/admin/postEdit.jsp") })
public class PostAction extends BaseAction implements ModelDriven<Post> {

	private static final long serialVersionUID = 1L;

	private static final Logger logger = Logger.getLogger(PostAction.class);

	private PostServiceI postService;

	public PostServiceI getPostService() {
		return postService;
	}

	@Autowired
	public void setPostService(PostServiceI postService) {
		this.postService = postService;
	}

	private Post post = new Post();

	public Post getModel() {
		return post;
	}

	/**
	 * 动态获取岗位树（当展开下级时才会加载下级岗位）
	 */
	public void doNotNeedSession_tree() {
		super.writeJson(postService.tree(post, false));
	}

	/**
	 * 一次性获取全部岗位树
	 */
	public void doNotNeedSession_treeRecursive() {
		super.writeJson(postService.tree(post, true));
	}

	public String post() {
		return "post";
	}

	/**
	 * 获得岗位treegrid
	 */
	public void treegrid() {
		super.writeJson(postService.treegrid(post));
	}

	/**
	 * 删除一个岗位
	 */
	public void delete() {
		Json j = new Json();
		try {
			postService.delete(post);
			j.setSuccess(true);
			j.setMsg("删除成功！");
			j.setObj(post.getCid());
		} catch (Exception e) {
			logger.error(ExceptionUtil.getExceptionMessage(e));
			j.setMsg("删除失败！岗位已使用!");
		}
		super.writeJson(j);
	}

	public String postAdd() {
		return "postAdd";
	}

	public void add() {
		Json j = new Json();
		try {
			postService.add(post);
			j.setSuccess(true);
			j.setMsg("添加成功！");
		} catch (Exception e) {
			logger.error(ExceptionUtil.getExceptionMessage(e));
			j.setMsg("添加失败！");
		}
		super.writeJson(j);
	}

	public String postEdit() {
		return "postEdit";
	}

	/**
	 * 编辑岗位
	 */
	public void edit() {
		Json j = new Json();
		try {
			postService.edit(post);
			j.setSuccess(true);
			j.setMsg("编辑成功!");
		} catch (Exception e) {
			logger.error(ExceptionUtil.getExceptionMessage(e));
			j.setMsg("编辑失败！");
		}
		writeJson(j);
	}

}
